@@ -21,46 +21,39 @@
 
 #include "generalConfigurationWidget.h"
 
+#include <QButtonGroup>
 #include <QCheckBox>
 #include <QPushButton>
-#include <QButtonGroup>
 
-#include <KMessageWidget>
 #include <KLocalizedString>
+#include <KMessageWidget>
 #include <QIcon>
 
-#include "logging.h"
 #include "defaults.h"
 #include "globals.h"
 #include "ksystemlogConfig.h"
-
-class GeneralConfigurationWidgetPrivate
-{
-public:
-    QButtonGroup *dateFormatGroup;
-    KMessageWidget *warningBox;
-};
+#include "logging.h"
 
 GeneralConfigurationWidget::GeneralConfigurationWidget()
     : QWidget()
-    , d(new GeneralConfigurationWidgetPrivate())
 {
     setupUi(this);
 
-    d->warningBox = new KMessageWidget(this);
-    d->warningBox->setVisible(false);
-    d->warningBox->setMessageType(KMessageWidget::Warning);
-    d->warningBox->setText(i18n("This mode is unavailable because its log files do not exist."));
-    d->warningBox->setCloseButtonVisible(false);
-    d->warningBox->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
-    startupModeVerticalLayout->addWidget(d->warningBox);
+    mWarningBox = new KMessageWidget(this);
+    mWarningBox->setVisible(false);
+    mWarningBox->setMessageType(KMessageWidget::Warning);
+    mWarningBox->setText(i18n("This mode is unavailable because its log files do not exist."));
+    mWarningBox->setCloseButtonVisible(false);
+    mWarningBox->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
+    startupModeVerticalLayout->addWidget(mWarningBox);
 
-    startupLogMode->addItem(QIcon::fromTheme(QStringLiteral(NO_MODE_ICON)), i18n("No Log Mode"),
-                            QVariant(QLatin1String("")));
-    foreach (LogMode *logMode, Globals::instance().logModes()) {
+    startupLogMode->addItem(QIcon::fromTheme(QStringLiteral(NO_MODE_ICON)), i18n("No Log Mode"), QVariant(QLatin1String("")));
+    const auto logModes = Globals::instance().logModes();
+    for (LogMode *logMode : logModes) {
         // Ignore this special case
-        if (logMode->id() == QLatin1String("openLogMode"))
+        if (logMode->id() == QLatin1String("openLogMode")) {
             continue;
+        }
 
         startupLogMode->addItem(logMode->icon(), logMode->name(), QVariant(logMode->id()));
     }
@@ -73,35 +66,33 @@ GeneralConfigurationWidget::GeneralConfigurationWidget()
 
     connect(colorizeLogLines, &QAbstractButton::clicked, this, &GeneralConfigurationWidget::configurationChanged);
 
-    d->dateFormatGroup = new QButtonGroup(this);
-    d->dateFormatGroup->addButton(formatLongDate, Globals::LongFormat);
-    d->dateFormatGroup->addButton(formatShortDate, Globals::ShortFormat);
-    d->dateFormatGroup->addButton(formatPreciseDate, Globals::PreciseFormat);
+    mDateFormatGroup = new QButtonGroup(this);
+    mDateFormatGroup->addButton(formatLongDate, Globals::LongFormat);
+    mDateFormatGroup->addButton(formatShortDate, Globals::ShortFormat);
+    mDateFormatGroup->addButton(formatPreciseDate, Globals::PreciseFormat);
 
-    connect(d->dateFormatGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &GeneralConfigurationWidget::configurationChanged);
+    connect(mDateFormatGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &GeneralConfigurationWidget::configurationChanged);
 
     addDateFormatExample();
 }
 
 GeneralConfigurationWidget::~GeneralConfigurationWidget()
 {
-    // dateFormatGroup is automatically deleted by Qt
-
-    delete d;
 }
 
 void GeneralConfigurationWidget::addDateFormatExample()
 {
-    foreach (QAbstractButton *button, d->dateFormatGroup->buttons()) {
-        Globals::DateFormat currentButtonFormat = (Globals::DateFormat)d->dateFormatGroup->id(button);
-        QString formattedDate = Globals::instance().formatDate(currentButtonFormat, QDateTime().currentDateTime());
+    const auto buttons = mDateFormatGroup->buttons();
+    for (QAbstractButton *button : buttons) {
+        const auto currentButtonFormat = static_cast<Globals::DateFormat>(mDateFormatGroup->id(button));
+        const QString formattedDate = Globals::instance().formatDate(currentButtonFormat, QDateTime().currentDateTime());
         button->setText(i18nc("Date format option (date example)", "%1 (%2)", button->text(), formattedDate));
     }
 }
 
 void GeneralConfigurationWidget::readConfig()
 {
-    for (int i = 0; i < startupLogMode->count(); ++i) {
+    for (int i = 0, total = startupLogMode->count(); i < total; ++i) {
         if (KSystemLogConfig::startupLogMode() == startupLogMode->itemData(i)) {
             startupLogMode->setCurrentIndex(i);
             break;
@@ -117,8 +108,8 @@ void GeneralConfigurationWidget::readConfig()
     colorizeLogLines->setChecked(KSystemLogConfig::colorizeLogLines());
 
     // KLocale::DateFormat dateFormat = (KLocale::DateFormat) KSystemLogConfig::dateFormat();
-    QLocale::FormatType dateFormat = (QLocale::FormatType)KSystemLogConfig::dateFormat();
-    QAbstractButton *selectedButton = d->dateFormatGroup->button(dateFormat);
+    const auto dateFormat = (QLocale::FormatType)KSystemLogConfig::dateFormat();
+    QAbstractButton *selectedButton = mDateFormatGroup->button(dateFormat);
     selectedButton->setChecked(true);
 }
 
@@ -133,7 +124,7 @@ void GeneralConfigurationWidget::saveConfig() const
     KSystemLogConfig::setDeleteProcessIdentifier(deleteProcessId->isChecked());
     KSystemLogConfig::setColorizeLogLines(colorizeLogLines->isChecked());
 
-    KSystemLogConfig::setDateFormat(d->dateFormatGroup->checkedId());
+    KSystemLogConfig::setDateFormat(mDateFormatGroup->checkedId());
 }
 
 void GeneralConfigurationWidget::defaultConfig()
@@ -146,22 +137,22 @@ bool GeneralConfigurationWidget::isValid() const
 {
     if (maxLines->value() > 0) {
         // Check if log files exist for selected mode.
-        QVariant modeID = startupLogMode->currentData();
+        const QVariant modeID = startupLogMode->currentData();
         if (!modeID.isNull()) {
-            QString modeString = modeID.toString();
+            const QString modeString = modeID.toString();
             LogMode *mode = Globals::instance().findLogMode(modeString);
             if (mode) {
                 if (!mode->filesExist()) {
                     logDebug() << "Log files are missing for mode" << mode->name();
-                    d->warningBox->setVisible(true);
+                    mWarningBox->setVisible(true);
                 } else {
                     logDebug() << "General configuration is valid";
-                    d->warningBox->setVisible(false);
+                    mWarningBox->setVisible(false);
                     return true;
                 }
             } else {
                 // Empty log mode is selected.
-                d->warningBox->setVisible(false);
+                mWarningBox->setVisible(false);
                 return true;
             }
         }
