@@ -24,14 +24,13 @@
 #include <KLocalizedString>
 #include <QElapsedTimer>
 
-#include "logging.h"
 #include "ksystemlogConfig.h"
+#include "logging.h"
 
 #include "logViewModel.h"
 
-#include "logMode.h"
 #include "logFileReader.h"
-
+#include "logMode.h"
 
 FileAnalyzer::FileAnalyzer(LogMode *logMode)
     : Analyzer(logMode)
@@ -51,7 +50,7 @@ void FileAnalyzer::watchLogFiles(bool enabled)
     // Enable the log file watching, by revert order to read the most top file at last, and be sure its line
     // will be kept
 
-    QListIterator<LogFileReader *> it(logFileReaders);
+    QListIterator<LogFileReader *> it(mLogFileReaders);
     it.toBack();
     while (it.hasPrevious()) {
         LogFileReader *logFileReader = it.previous();
@@ -64,22 +63,22 @@ void FileAnalyzer::deleteLogFiles()
     watchLogFiles(false);
 
     // Remove the watching on the monitored files
-    foreach (LogFileReader *logFileReader, logFileReaders) {
+    foreach (LogFileReader *logFileReader, mLogFileReaders) {
         logDebug() << "Remove file : " << logFileReader->logFile().url().toLocalFile();
         delete logFileReader;
     }
 
-    logFileReaders.clear();
+    mLogFileReaders.clear();
 }
 
-void FileAnalyzer::setLogFiles(const QList<LogFile> &logFiles)
+void FileAnalyzer::setLogFiles(const QVector<LogFile> &logFiles)
 {
     // Remove previous files
     deleteLogFiles();
 
-    foreach (const LogFile &logFile, logFiles) {
+    for (const LogFile &logFile : logFiles) {
         LogFileReader *logFileReader = createLogFileReader(logFile);
-        logFileReaders.append(logFileReader);
+        mLogFileReaders.append(logFileReader);
 
         connect(logFileReader, &LogFileReader::contentChanged, this, &FileAnalyzer::logFileChanged);
         connect(logFileReader, &LogFileReader::statusBarChanged, this, &Analyzer::statusBarChanged);
@@ -87,22 +86,22 @@ void FileAnalyzer::setLogFiles(const QList<LogFile> &logFiles)
     }
 }
 
-void FileAnalyzer::logFileChanged(LogFileReader *logFileReader, ReadingMode readingMode,
-                                  const QStringList &content)
+void FileAnalyzer::logFileChanged(LogFileReader *logFileReader, ReadingMode readingMode, const QStringList &content)
 {
-    QString filePath = logFileReader->logFile().url().toLocalFile();
-    if (readingMode == Analyzer::FullRead)
+    const QString filePath = logFileReader->logFile().url().toLocalFile();
+    if (readingMode == Analyzer::FullRead) {
         logDebug() << "File " << filePath << " has been modified on full read.";
-    else
+    } else {
         logDebug() << "File " << filePath << " has been modified on partial read";
+    }
 
-    if (parsingPaused == true) {
+    if (mParsingPaused) {
         logDebug() << "Pause enabled. Nothing read.";
         return;
     }
 
     logDebug() << "Locking file modifications of " << filePath;
-    insertionLocking.lock();
+    mInsertionLocking.lock();
     logDebug() << "Unlocking file modifications of " << filePath;
 
     QElapsedTimer benchmark;
@@ -110,43 +109,40 @@ void FileAnalyzer::logFileChanged(LogFileReader *logFileReader, ReadingMode read
 
     int insertedLogLineCount;
 
-    logViewModel->startingMultipleInsertions();
+    mLogViewModel->startingMultipleInsertions();
 
     if (readingMode == Analyzer::UpdatingRead) {
         insertedLogLineCount = insertLines(content, logFileReader->logFile(), Analyzer::UpdatingRead);
     } else {
         logDebug() << "Reading file " << filePath;
 
-        emit statusBarChanged(i18n("Opening '%1'...", filePath));
+        Q_EMIT statusBarChanged(i18n("Opening '%1'...", filePath));
 
         // Inform that we are now reading the "index" file
-        emit readFileStarted(*logMode, logFileReader->logFile(),
-                             logFileReaders.count() - logFileReaders.indexOf(logFileReader),
-                             logFileReaders.count());
+        Q_EMIT readFileStarted(*mLogMode, logFileReader->logFile(), mLogFileReaders.count() - mLogFileReaders.indexOf(logFileReader), mLogFileReaders.count());
 
         insertedLogLineCount = insertLines(content, logFileReader->logFile(), Analyzer::FullRead);
 
-        emit statusBarChanged(i18n("Log file '%1' loaded successfully.", filePath));
+        Q_EMIT statusBarChanged(i18n("Log file '%1' loaded successfully.", filePath));
     }
 
-    logViewModel->endingMultipleInsertions(readingMode, insertedLogLineCount);
+    mLogViewModel->endingMultipleInsertions(readingMode, insertedLogLineCount);
 
     // Inform connected LoadingBar that the reading is now finished
-    emit readEnded();
+    Q_EMIT readEnded();
 
     // Inform LogManager that new lines have been added
-    emit logUpdated(insertedLogLineCount);
+    Q_EMIT logUpdated(insertedLogLineCount);
 
     // Inform MainWindow status bar
-    emit statusBarChanged(i18n("Log file '%1' has changed.", filePath));
+    Q_EMIT statusBarChanged(i18n("Log file '%1' has changed.", filePath));
 
     logDebug() << "Updating log files in " << benchmark.elapsed() << " ms";
 
-    insertionLocking.unlock();
+    mInsertionLocking.unlock();
 }
 
-int FileAnalyzer::insertLines(const QStringList &bufferedLines, const LogFile &logFile,
-                              ReadingMode readingMode)
+int FileAnalyzer::insertLines(const QStringList &bufferedLines, const LogFile &logFile, ReadingMode readingMode)
 {
     logDebug() << "Inserting lines...";
 
@@ -181,9 +177,9 @@ int FileAnalyzer::insertLines(const QStringList &bufferedLines, const LogFile &l
 
     int insertedLogLineCount = 0;
     while (currentPosition < bufferedLines.size()) {
-        QString buffer(it.next());
+        const QString buffer(it.next());
 
-        bool inserted = insertLine(buffer, logFile, readingMode);
+        const bool inserted = insertLine(buffer, logFile, readingMode);
         if (inserted) {
             insertedLogLineCount++;
         }
@@ -205,7 +201,7 @@ bool FileAnalyzer::insertLine(const QString &buffer, const LogFile &originalFile
     LogLine *line = parseMessage(buffer, originalFile);
 
     // Invalid log line
-    if (line == nullptr) {
+    if (!line) {
         return false;
     }
 
@@ -214,5 +210,5 @@ bool FileAnalyzer::insertLine(const QString &buffer, const LogFile &originalFile
         line->setRecent(false);
     }
 
-    return logViewModel->insertNewLogLine(line);
+    return mLogViewModel->insertNewLogLine(line);
 }
