@@ -22,26 +22,22 @@
 #ifndef LOG_FILE_H
 #define LOG_FILE_H
 
-#include <QObject>
 #include <QDataStream>
 #include <QDebug>
+#include <QObject>
 #include <QUrl>
 
 class LogLevel;
 
-class LogFilePrivate;
-
-class LogFile : public QObject
+class LogFile
 {
-    Q_OBJECT
-
 public:
     LogFile();
 
     LogFile(const LogFile &logFile);
     LogFile(const QUrl &url, LogLevel *defaultLogLevel);
 
-    virtual ~LogFile();
+    ~LogFile();
 
     bool operator==(const LogFile &other) const;
 
@@ -52,7 +48,9 @@ public:
     LogLevel *defaultLogLevel() const;
 
 private:
-    LogFilePrivate *const d;
+    QUrl mUrl;
+
+    LogLevel *mDefaultLogLevel = nullptr;
 };
 
 QDataStream &operator<<(QDataStream &out, const LogFile &column);
