@@ -22,8 +22,8 @@
 #ifndef LOG_MODE_CONFIGURATION_H
 #define LOG_MODE_CONFIGURATION_H
 
-#include <QObject>
 #include <QList>
+#include <QObject>
 #include <QStringList>
 
 #include "logFile.h"
@@ -35,17 +35,17 @@ class LogModeConfiguration : public QObject
     Q_OBJECT
 
 public:
-    LogModeConfiguration();
+    explicit LogModeConfiguration(QObject *parent = nullptr);
 
-    virtual ~LogModeConfiguration();
+    ~LogModeConfiguration() override;
 
     LogFile findGenericLogFile(const QString &file);
-    QList<LogFile> findGenericLogFiles(const QStringList &files);
+    QVector<LogFile> findGenericLogFiles(const QStringList &files);
 
-    QList<LogFile> findNoModeLogFiles(const QStringList &stringList);
+    QVector<LogFile> findNoModeLogFiles(const QStringList &stringList);
 
 protected:
-    KSystemLogConfig *configuration;
+    KSystemLogConfig *mConfiguration = nullptr;
 };
 
 #endif // _LOG_MODE_CONFIGURATION_H
