@@ -22,31 +22,29 @@
 #ifndef LOG_VIEW_FILTER_WIDGET_H
 #define LOG_VIEW_FILTER_WIDGET_H
 
-#include <QWidget>
 #include <QStandardItem>
+#include <QWidget>
 
 #include <KTreeWidgetSearchLine>
 
+#include "globals.h"
 #include "logViewColumns.h"
 
 class LogViewWidget;
 class LogViewWidgetSearchLine;
-class KComboBox;
-
-class LogViewWidgetSearchLinePrivate;
-class LogViewFilterWidgetPrivate;
+class QComboBox;
 
 class LogViewFilterWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    LogViewFilterWidget();
+    explicit LogViewFilterWidget(QWidget *parent = nullptr);
 
-    ~LogViewFilterWidget();
+    ~LogViewFilterWidget() override;
 
-    KComboBox *filterList();
-    LogViewWidgetSearchLine *filterLine();
+    QComboBox *filterList() const;
+    LogViewWidgetSearchLine *filterLine() const;
 
 public Q_SLOTS:
     void updateFilterColumns(const LogViewColumns &list);
@@ -60,8 +58,16 @@ Q_SIGNALS:
 
 private:
     void initSearchListFilter();
+    LogViewWidgetSearchLine *mFilterLine = nullptr;
 
-    LogViewFilterWidgetPrivate *const d;
+    /**
+     * Filter of the column list
+     */
+    QComboBox *mFilterList = nullptr;
+
+    QComboBox *mPrioritiesComboBox = nullptr;
+
+    QStandardItemModel *mPrioritiesModel = nullptr;
 };
 
 class LogViewWidgetSearchLine : public KTreeWidgetSearchLine
@@ -69,9 +75,9 @@ class LogViewWidgetSearchLine : public KTreeWidgetSearchLine
     Q_OBJECT
 
 public:
-    LogViewWidgetSearchLine();
+    explicit LogViewWidgetSearchLine(QWidget *parent = nullptr);
 
-    ~LogViewWidgetSearchLine();
+    ~LogViewWidgetSearchLine() override;
 
     // Silence compiler warning
     using KTreeWidgetSearchLine::updateSearch;
@@ -88,7 +94,7 @@ Q_SIGNALS:
     void treeWidgetUpdated();
 
 private:
-    LogViewWidgetSearchLinePrivate *const d;
+    bool mPriorities[Globals::LOG_LEVEL_NUM];
 };
 
 #endif // LOG_VIEW_FILTER_WIDGET_H
