@@ -21,65 +21,52 @@
 
 #include "logViewModel.h"
 
-#include "view.h"
 #include "logLine.h"
+#include "view.h"
 
-#include "logViewWidgetItem.h"
-#include "logViewWidget.h"
 #include "logModeItemBuilder.h"
+#include "logViewWidget.h"
+#include "logViewWidgetItem.h"
 
 #include "logging.h"
 
 #include "ksystemlogConfig.h"
 
-class LogViewModelPrivate
-{
-public:
-    LogViewWidget *logViewWidget;
-
-    LogViewWidgetItem *oldestItem;
-
-    int concurrentMultipleInsertions;
-};
-
 LogViewModel::LogViewModel(LogViewWidget *logViewWidget)
     : QObject(logViewWidget)
-    , d(new LogViewModelPrivate())
 {
-    d->logViewWidget = logViewWidget;
-    d->oldestItem = nullptr;
-
-    d->concurrentMultipleInsertions = 0;
+    mLogViewWidget = logViewWidget;
 }
 
 LogViewModel::~LogViewModel()
 {
-    delete d;
 }
 
 bool LogViewModel::logLineAlreadyExists(LogLine *line) const
 {
-    LogViewWidgetItem *item = d->logViewWidget->findItem(line);
-    if (item != nullptr)
+    LogViewWidgetItem *item = mLogViewWidget->findItem(line);
+    if (item) {
         return true;
+    }
 
     return false;
 }
 
-QList<LogLine *> LogViewModel::logLines()
+QList<LogLine *> LogViewModel::logLines() const
 {
-    return d->logViewWidget->logLines();
+    return mLogViewWidget->logLines();
 }
 
 int LogViewModel::itemCount() const
 {
-    return d->logViewWidget->itemCount();
+    return mLogViewWidget->itemCount();
 }
 
 bool LogViewModel::isEmpty() const
 {
-    if (d->logViewWidget->itemCount() == 0)
+    if (mLogViewWidget->itemCount() == 0) {
         return true;
+    }
 
     return false;
 }
@@ -87,7 +74,7 @@ bool LogViewModel::isEmpty() const
 void LogViewModel::removeRecentStatusOfLogLines()
 {
     // The older lines are no longer recent
-    foreach (LogViewWidgetItem *item, d->logViewWidget->items()) {
+    foreach (LogViewWidgetItem *item, mLogViewWidget->items()) {
         item->logLine()->setRecent(false);
     }
 }
@@ -97,19 +84,19 @@ void LogViewModel::startingMultipleInsertions()
     bool hasLocked = false;
 
     // Check the lock before adding this as locker
-    if (lockMultipleInsertions() == true) {
+    if (lockMultipleInsertions()) {
         hasLocked = true;
     }
 
     // Add a lock
-    d->concurrentMultipleInsertions++;
+    mConcurrentMultipleInsertions++;
 
-    if (hasLocked == true) {
+    if (hasLocked) {
         logDebug() << "Starting multiple insertions...";
 
-        emit(processingMultipleInsertions(true));
+        Q_EMIT processingMultipleInsertions(true);
 
-        d->logViewWidget->setUpdatesEnabled(false);
+        mLogViewWidget->setUpdatesEnabled(false);
 
         // Remove all recent states of previous log lines
         removeRecentStatusOfLogLines();
@@ -119,37 +106,37 @@ void LogViewModel::startingMultipleInsertions()
 void LogViewModel::endingMultipleInsertions(Analyzer::ReadingMode readingMode, int insertedLogLineCount)
 {
     // Remove a lock
-    d->concurrentMultipleInsertions--;
+    mConcurrentMultipleInsertions--;
 
-    if (lockMultipleInsertions() == true) {
+    if (lockMultipleInsertions()) {
         logDebug() << "Ending multiple insertions...";
 
         // Scroll to the newest item if some lines have been added
         if (insertedLogLineCount > 0) {
-            d->logViewWidget->scrollToNewestItem();
+            mLogViewWidget->scrollToNewestItem();
         }
 
         if (readingMode == Analyzer::FullRead) {
-            d->logViewWidget->resizeColumns();
+            mLogViewWidget->resizeColumns();
         }
 
         logDebug() << "Enabling log view widget refresh...";
-        d->logViewWidget->setUpdatesEnabled(true);
+        mLogViewWidget->setUpdatesEnabled(true);
 
-        emit(processingMultipleInsertions(false));
+        Q_EMIT processingMultipleInsertions(false);
     }
 }
 
 bool LogViewModel::lockMultipleInsertions()
 {
-    if (d->concurrentMultipleInsertions == 0) {
+    if (mConcurrentMultipleInsertions == 0) {
         return true;
     }
 
     // Debug messages
-    if (d->concurrentMultipleInsertions > 0) {
+    if (mConcurrentMultipleInsertions > 0) {
         logDebug() << "Existing multiple insertions request is still active";
-    } else if (d->concurrentMultipleInsertions < 0) {
+    } else if (mConcurrentMultipleInsertions < 0) {
         logCritical() << "Existing multiple insertions forgot to call this method";
     }
 
@@ -158,28 +145,31 @@ bool LogViewModel::lockMultipleInsertions()
 
 bool LogViewModel::isProcessingMultipleInsertions() const
 {
-    if (d->concurrentMultipleInsertions == 0)
+    if (mConcurrentMultipleInsertions == 0) {
         return false;
-    else
+    } else {
         return true;
+    }
 }
 
 void LogViewModel::clear()
 {
-    d->logViewWidget->clear();
+    mLogViewWidget->clear();
 
     // Reinit Oldest item
-    d->oldestItem = nullptr;
+    mOldestItem = nullptr;
 }
 
 bool LogViewModel::isNewer(LogLine *newLine) const
 {
     // No element in the list in this case
-    if (d->oldestItem == nullptr)
+    if (!mOldestItem) {
         return true;
+    }
 
-    if (newLine->isNewerThan(*(d->oldestItem->logLine())))
+    if (newLine->isNewerThan(*(mOldestItem->logLine()))) {
         return true;
+    }
 
     return false;
 }
@@ -188,30 +178,30 @@ void LogViewModel::removeOldestLogLine()
 {
     // logDebug() << "Removing oldest log line";
 
-    if (isEmpty() == true) {
+    if (isEmpty()) {
         return;
     }
 
-    if (d->oldestItem == nullptr) {
+    if (!mOldestItem) {
         logWarning() << "Oldest item is null";
         return;
     }
 
     // Remove the oldest item from the list
-    d->logViewWidget->takeTopLevelItem(d->logViewWidget->indexOfTopLevelItem(d->oldestItem));
+    mLogViewWidget->takeTopLevelItem(mLogViewWidget->indexOfTopLevelItem(mOldestItem));
 
-    delete d->oldestItem;
-    d->oldestItem = nullptr;
+    delete mOldestItem;
+    mOldestItem = nullptr;
 
     // Find the next oldest item
-    foreach (LogViewWidgetItem *item, d->logViewWidget->items()) {
-        if (d->oldestItem == nullptr) {
-            d->oldestItem = item;
+    foreach (LogViewWidgetItem *item, mLogViewWidget->items()) {
+        if (!mOldestItem) {
+            mOldestItem = item;
             continue;
         }
 
-        if (d->oldestItem->logLine()->isNewerThan(*(item->logLine()))) {
-            d->oldestItem = item;
+        if (mOldestItem->logLine()->isNewerThan(*(item->logLine()))) {
+            mOldestItem = item;
         }
     }
 }
@@ -219,21 +209,21 @@ void LogViewModel::removeOldestLogLine()
 void LogViewModel::insert(LogLine *line)
 {
     // The item is automatically added to the LogViewWidget
-    LogViewWidgetItem *item = new LogViewWidgetItem(d->logViewWidget, line);
+    auto item = new LogViewWidgetItem(mLogViewWidget, line);
 
     // Update the oldest item
-    if (d->oldestItem == nullptr) {
-        d->oldestItem = item;
-    } else if (d->oldestItem->logLine()->isNewerThan(*line)) {
-        d->oldestItem = item;
+    if (!mOldestItem) {
+        mOldestItem = item;
+    } else if (mOldestItem->logLine()->isNewerThan(*line)) {
+        mOldestItem = item;
     }
 }
 
 bool LogViewModel::insertNewLogLine(LogLine *line)
 {
     // If the Delete Duplicated Line option is checked
-    if (KSystemLogConfig::deleteDuplicatedLines() == true) {
-        if (logLineAlreadyExists(line) == true) {
+    if (KSystemLogConfig::deleteDuplicatedLines()) {
+        if (logLineAlreadyExists(line)) {
             delete line;
             return false;
         }
@@ -246,7 +236,7 @@ bool LogViewModel::insertNewLogLine(LogLine *line)
         return true;
     }
     // If the line is newer, it can be inserted
-    else if (isNewer(line) == true) {
+    else if (isNewer(line)) {
         removeOldestLogLine();
         insert(line);
 
