@@ -22,24 +22,22 @@
 #ifndef LOG_VIEW_SEARCH_WIDGET_H
 #define LOG_VIEW_SEARCH_WIDGET_H
 
-#include <QWidget>
 #include <QTreeWidgetItemIterator>
+#include <QWidget>
 
 #include "ui_logViewSearchWidgetBase.h"
 
 class LogViewWidget;
 class LogViewWidgetItem;
 
-class LogViewSearchWidgetPrivate;
-
 class LogViewSearchWidget : public QWidget, public Ui::LogViewSearchWidgetBase
 {
     Q_OBJECT
 
 public:
-    LogViewSearchWidget();
+    explicit LogViewSearchWidget(QWidget *parent = nullptr);
 
-    ~LogViewSearchWidget();
+    ~LogViewSearchWidget() override;
 
     void setTreeWidget(LogViewWidget *logViewWidget);
 
@@ -75,8 +73,12 @@ private:
 
     inline void initIterator(QTreeWidgetItemIterator &it, Direction direction);
     inline void iteratorJump(QTreeWidgetItemIterator &it, Direction direction);
+    LogViewWidget *mLogViewWidget = nullptr;
 
-    LogViewSearchWidgetPrivate *const d;
+    QColor mSearchLineBaseColor;
+    QColor mSearchLineTextColor;
+
+    QTimer *mMessageHidingTimer = nullptr;
 };
 
 #endif //_LOG_VIEW_SEARCH_WIDGET_H
