@@ -26,14 +26,11 @@
 #include <KLocalizedString>
 
 #include "ksystemlog_version.h"
-#include "mainWindow.h"
 #include "logging.h"
+#include "mainWindow.h"
 
 int main(int argc, char **argv)
 {
-    // Enable debug output:
-    // QLoggingCategory::setFilterRules(QStringLiteral("ksystemlog.debug = true"));
-
     // enable high dpi support
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
@@ -42,28 +39,30 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("ksystemlog");
 
-    KAboutData about(QStringLiteral("ksystemlog"), i18n("KSystemlog"), QStringLiteral(KSYSTEMLOG_VERSION_STRING),
-                     i18n("System Logs Viewer by KDE"), KAboutLicense::GPL_V2,
+    KAboutData about(QStringLiteral("ksystemlog"),
+                     i18n("KSystemlog"),
+                     QStringLiteral(KSYSTEMLOG_VERSION_STRING),
+                     i18n("System Logs Viewer by KDE"),
+                     KAboutLicense::GPL_V2,
                      i18n("(C) 2007-2015, Nicolas Ternisien"),
                      i18n("Do not hesitate to report bugs and problems to Nicolas Ternisien <a "
                           "href='mailto:nicolas.ternisien@gmail.com'>nicolas.ternisien@gmail.com</a>"),
-                     QStringLiteral("https://www.kde.org/applications/system/ksystemlog/"), QString());
+                     QStringLiteral("https://apps.kde.org/en/ksystemlog"),
+                     QString());
 
     about.setOrganizationDomain("kde.org");
 
-    about.addAuthor(i18n("Nicolas Ternisien"), i18n("Main developer"),
+    about.addAuthor(i18n("Nicolas Ternisien"),
+                    i18n("Main developer"),
                     QStringLiteral("nicolas.ternisien@gmail.com"),
                     QStringLiteral("https://www.forum-software.org"));
-    about.addAuthor(i18n("Vyacheslav Matyushin"), i18n("Journald mode, bugfixes"),
-                    QStringLiteral("v.matyushin@gmail.com"));
+    about.addAuthor(i18n("Vyacheslav Matyushin"), i18n("Journald mode, bugfixes"), QStringLiteral("v.matyushin@gmail.com"));
     about.addCredit(i18n("Bojan Djurkovic"), i18n("Log Printing"), QStringLiteral("dbojan@gmail.com"));
+    about.addCredit(i18n("Laurent Montel"), i18n("Bug Fixing"), QStringLiteral("montel@kde.org"));
 
     KAboutData::setApplicationData(about);
 
-    app.setApplicationName(about.componentName());
     app.setApplicationDisplayName(about.displayName());
-    app.setOrganizationDomain(about.organizationDomain());
-    app.setApplicationVersion(about.version());
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("utilities-log-viewer")));
 
@@ -88,12 +87,12 @@ int main(int argc, char **argv)
 
         const QStringList args = parser.positionalArguments();
 
-        if (args.count() == 0) {
+        if (args.isEmpty()) {
             new KSystemLog::MainWindow();
         } else {
             // KSystemLog::MainWindow* mainWindow;
             new KSystemLog::MainWindow();
-            for (int i = 0; i < args.count(); i++) {
+            for (int i = 0, total = args.count(); i < total; ++i) {
                 logDebug() << "Loading file " << args.at(i);
 
                 // TODO Implement this kind of loading
