@@ -49,7 +49,7 @@ public:
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _AUTHENTICATION_LOG_MODE_H
