@@ -35,14 +35,14 @@ class FileList : public QWidget, public Ui::FileListBase
 {
     Q_OBJECT
 public:
-    FileList(QWidget *parent, const QString &descriptionText);
-    virtual ~FileList();
+    explicit FileList(QWidget *parent, const QString &descriptionText);
+    ~FileList() override;
 
     int count() const;
 
     bool isEmpty() const;
 
-    QStringList paths();
+    QStringList paths() const;
 
     void addPaths(const QStringList &paths);
 
@@ -80,9 +80,9 @@ protected:
      */
     QVBoxLayout *buttonsLayout();
 
-    FileListHelper fileListHelper;
+    FileListHelper mFileListHelper;
 
-    KMessageWidget *warningBox;
+    KMessageWidget *mWarningBox = nullptr;
 };
 
 #endif //_FILE_LIST_H
