@@ -22,8 +22,8 @@
 #ifndef LOG_MODE_GENERIC_CONFIGURATION_H
 #define LOG_MODE_GENERIC_CONFIGURATION_H
 
-#include <QStringList>
 #include <QList>
+#include <QStringList>
 
 #include "logFile.h"
 
@@ -36,9 +36,8 @@ class GenericLogModeConfiguration : public LogModeConfiguration
     Q_OBJECT
 
 public:
-    GenericLogModeConfiguration(const QString &configurationGroup, const QStringList &defaultLogFilesPaths,
-                                const QList<int> &defaultLogFilesLevels);
-    virtual ~GenericLogModeConfiguration();
+    GenericLogModeConfiguration(const QString &configurationGroup, const QStringList &defaultLogFilesPaths, const QList<int> &defaultLogFilesLevels);
+    ~GenericLogModeConfiguration() override;
 
     QStringList logFilesPaths() const;
 
@@ -48,10 +47,12 @@ public:
 
     void setLogFilesLevels(const QList<int> &logFilesLevels);
 
-    QList<LogFile> findGenericLogFiles();
+    QVector<LogFile> findGenericLogFiles() const;
 
 private:
-    GenericLogModeConfigurationPrivate *const d;
+    QStringList mLogFilesPaths;
+
+    QList<int> mLogFilesLevels;
 };
 
 #endif // _LOG_MODE_GENERIC_CONFIGURATION_H
