@@ -24,8 +24,8 @@
 
 #include <QDateTime>
 
-#include <QString>
 #include <QMap>
+#include <QString>
 
 /**
  * TODO Fork this class in SyslogParsingHelper and HttpParsingHelper
@@ -49,7 +49,7 @@ public:
      * of trying to search it in string
      */
     QDateTime parseSyslogDateTime(const QString &dateTime);
-    QString syslogDateTimeRegexp();
+    QString syslogDateTimeRegexp() const;
 
     QString parseSize(const QString &size);
 
@@ -62,9 +62,9 @@ private:
 
     static ParsingHelper *self;
 
-    QMap<QString, int> mapMonths;
+    QMap<QString, int> mMapMonths;
 
-    QMap<QString, QString> mapHTTPResponse;
+    QMap<QString, QString> mMapHTTPResponse;
 };
 
 #endif
