@@ -44,11 +44,11 @@ class CronLogMode : public LogMode
 public:
     explicit CronLogMode();
 
-    ~CronLogMode();
+    ~CronLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _CRON_LOG_MODE_H
