@@ -31,36 +31,21 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 class CupsAccessItemBuilder : public LogModeItemBuilder
 {
 public:
-    CupsAccessItemBuilder() {}
-
-    virtual ~CupsAccessItemBuilder() {}
-
-    QString createFormattedText(LogLine *line) const override
+    CupsAccessItemBuilder()
     {
-        QString result;
-
-        QListIterator<QString> it(line->logItems());
-
-        result.append(QLatin1String("<table>"));
-
-        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
-        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
-        result.append(labelMessageFormat(i18n("Hostname:"), it.next()));
-        result.append(labelMessageFormat(i18n("Identification:"), it.next()));
-        result.append(labelMessageFormat(i18n("Username:"), it.next()));
-        result.append(labelMessageFormat(i18n("HTTP Response:"), it.next()));
-        result.append(labelMessageFormat(i18n("Bytes Sent:"), it.next()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
+
+    ~CupsAccessItemBuilder() override
+    {
+    }
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _CUPS_ACCESS_ITEM_BUILDER_H
