@@ -23,9 +23,9 @@
 #include "journaldNetworkAnalyzer.h"
 #include "journaldConfiguration.h"
 #include "ksystemlogConfig.h"
-#include "logging.h"
-#include "logViewModel.h"
 #include "logFile.h"
+#include "logViewModel.h"
+#include "logging.h"
 
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -38,41 +38,38 @@
 JournaldNetworkAnalyzer::JournaldNetworkAnalyzer(LogMode *mode, const JournaldAnalyzerOptions &options)
     : JournaldAnalyzer(mode)
 {
-    m_address = options.address;
+    mAddress = options.address;
 
-    connect(&m_networkManager, &QNetworkAccessManager::sslErrors, this, &JournaldNetworkAnalyzer::sslErrors);
+    connect(&mNetworkManager, &QNetworkAccessManager::sslErrors, this, &JournaldNetworkAnalyzer::sslErrors);
 
-    JournaldConfiguration *configuration = mode->logModeConfiguration<JournaldConfiguration *>();
+    auto *configuration = mode->logModeConfiguration<JournaldConfiguration *>();
 
-    m_baseUrl = QStringLiteral("%1://%2:%3/")
-                    .arg(m_address.https ? QStringLiteral("https") : QStringLiteral("http"))
-                    .arg(m_address.address)
-                    .arg(m_address.port);
+    mBaseUrl = QStringLiteral("%1://%2:%3/").arg(mAddress.https ? QStringLiteral("https") : QStringLiteral("http")).arg(mAddress.address).arg(mAddress.port);
 
-    m_entriesUrlUpdating = m_baseUrl + QStringLiteral("entries");
-    m_entriesUrlFull = m_entriesUrlUpdating;
+    mEntriesUrlUpdating = mBaseUrl + QStringLiteral("entries");
+    mEntriesUrlFull = mEntriesUrlUpdating;
 
     QString filterPrefix;
     if (configuration->displayCurrentBootOnly()) {
-        m_entriesUrlUpdating.append(QStringLiteral("?boot&follow"));
-        m_entriesUrlFull.append(QStringLiteral("?boot"));
+        mEntriesUrlUpdating.append(QStringLiteral("?boot&follow"));
+        mEntriesUrlFull.append(QStringLiteral("?boot"));
         filterPrefix = QStringLiteral("&");
     } else {
-        m_entriesUrlUpdating.append(QStringLiteral("?follow"));
+        mEntriesUrlUpdating.append(QStringLiteral("?follow"));
         filterPrefix = QStringLiteral("?");
     }
 
     if (!options.filter.isEmpty()) {
-        m_entriesUrlUpdating.append(QStringLiteral("&") + options.filter);
-        m_entriesUrlFull.append(filterPrefix + options.filter);
+        mEntriesUrlUpdating.append(QStringLiteral("&") + options.filter);
+        mEntriesUrlFull.append(filterPrefix + options.filter);
     }
 
-    m_syslogIdUrl = m_baseUrl + QStringLiteral("fields/SYSLOG_IDENTIFIER");
-    m_systemdUnitsUrl = m_baseUrl + QStringLiteral("fields/_SYSTEMD_UNIT");
+    mSyslogIdUrl = mBaseUrl + QStringLiteral("fields/SYSLOG_IDENTIFIER");
+    mSystemdUnitsUrl = mBaseUrl + QStringLiteral("fields/_SYSTEMD_UNIT");
 
-    m_filterName = options.filter.section(QChar::fromLatin1('='), 1);
+    mFilterName = options.filter.section(QChar::fromLatin1('='), 1);
 
-    m_reply = nullptr;
+    mReply = nullptr;
 }
 
 void JournaldNetworkAnalyzer::watchLogFiles(bool enabled)
@@ -80,63 +77,59 @@ void JournaldNetworkAnalyzer::watchLogFiles(bool enabled)
     if (enabled) {
         sendRequest(RequestType::SyslogIds);
     } else {
-        m_cursor.clear();
+        mCursor.clear();
         updateStatus(QString());
-        if (m_reply) {
-            m_reply->abort();
-            m_reply->deleteLater();
-            m_reply = nullptr;
+        if (mReply) {
+            mReply->abort();
+            mReply->deleteLater();
+            mReply = nullptr;
         }
     }
 }
 
 QStringList JournaldNetworkAnalyzer::units() const
 {
-    return m_systemdUnits;
+    return mSystemdUnits;
 }
 
 QStringList JournaldNetworkAnalyzer::syslogIdentifiers() const
 {
-    return m_syslogIdentifiers;
+    return mSyslogIdentifiers;
 }
 
 void JournaldNetworkAnalyzer::httpFinished()
 {
-    QByteArray data = m_reply->readAll();
-    if (m_currentRequest == RequestType::EntriesFull) {
+    QByteArray data = mReply->readAll();
+    if (mCurrentRequest == RequestType::EntriesFull) {
         if (data.size()) {
             parseEntries(data, FullRead);
             updateStatus(i18n("Connected"));
         }
-        if (!m_cursor.isEmpty())
+        if (!mCursor.isEmpty()) {
             sendRequest(RequestType::EntriesUpdate);
-        else {
+        } else {
             logWarning() << "Network journal analyzer failed to extract cursor string. "
                             "Journal updates will be unavailable.";
         }
     } else {
         QString identifiersString = QString::fromUtf8(data);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList identifiersList = identifiersString.split(QChar::fromLatin1('\n'), QString::SkipEmptyParts);
-#else
         QStringList identifiersList = identifiersString.split(QChar::fromLatin1('\n'), Qt::SkipEmptyParts);
-#endif
-        switch (m_currentRequest) {
+        switch (mCurrentRequest) {
         case RequestType::SyslogIds:
-            m_syslogIdentifiers = identifiersList;
-            m_syslogIdentifiers.sort();
+            mSyslogIdentifiers = identifiersList;
+            mSyslogIdentifiers.sort();
             sendRequest(RequestType::Units);
             break;
         case RequestType::Units: {
-            m_systemdUnits = identifiersList;
-            m_systemdUnits.sort();
-            JournaldLogMode *journalLogMode = dynamic_cast<JournaldLogMode *>(logMode);
+            mSystemdUnits = identifiersList;
+            mSystemdUnits.sort();
+            auto *journalLogMode = dynamic_cast<JournaldLogMode *>(mLogMode);
             JournalFilters filters;
-            filters.syslogIdentifiers = m_syslogIdentifiers;
-            filters.systemdUnits = m_systemdUnits;
-            journalLogMode->updateJournalFilters(m_address, filters);
+            filters.syslogIdentifiers = mSyslogIdentifiers;
+            filters.systemdUnits = mSystemdUnits;
+            journalLogMode->updateJournalFilters(mAddress, filters);
             // Regenerate the "Logs" submenu to include new syslog identifiers and systemd units.
-            emit logMode->menuChanged();
+            Q_EMIT mLogMode->menuChanged();
             sendRequest(RequestType::EntriesFull);
             break;
         }
@@ -148,19 +141,21 @@ void JournaldNetworkAnalyzer::httpFinished()
 
 void JournaldNetworkAnalyzer::httpReadyRead()
 {
-    if (m_currentRequest == RequestType::EntriesUpdate) {
-        QByteArray data = m_reply->readAll();
+    if (mCurrentRequest == RequestType::EntriesUpdate) {
+        QByteArray data = mReply->readAll();
         parseEntries(data, UpdatingRead);
     }
 }
 
 void JournaldNetworkAnalyzer::httpError(QNetworkReply::NetworkError code)
 {
-    if (parsingPaused)
+    if (mParsingPaused) {
         return;
+    }
 
-    if (code == QNetworkReply::OperationCanceledError)
+    if (code == QNetworkReply::OperationCanceledError) {
         return;
+    }
 
     updateStatus(i18n("Connection error"));
     logWarning() << "Network journald connection error:" << code;
@@ -174,7 +169,7 @@ void JournaldNetworkAnalyzer::sslErrors(QNetworkReply *reply, const QList<QSslEr
 
 void JournaldNetworkAnalyzer::parseEntries(QByteArray &data, Analyzer::ReadingMode readingMode)
 {
-    if (parsingPaused) {
+    if (mParsingPaused) {
         logDebug() << "Parsing is paused, discarding journald entries.";
         return;
     }
@@ -183,38 +178,42 @@ void JournaldNetworkAnalyzer::parseEntries(QByteArray &data, Analyzer::ReadingMo
     QList<JournalEntry> entries;
     for (int i = 0; i < items.size(); i++) {
         QByteArray &item = items[i];
-        if (item.isEmpty())
+        if (item.isEmpty()) {
             continue;
+        }
         item.prepend('{');
         QJsonParseError jsonError{};
         QJsonDocument doc = QJsonDocument::fromJson(item, &jsonError);
-        if (jsonError.error != 0)
+        if (jsonError.error != 0) {
             continue;
+        }
         QJsonObject object = doc.object();
 
         if ((readingMode == FullRead) && (i == items.size() - 1)) {
-            m_cursor = object[QStringLiteral("__CURSOR")].toString();
+            mCursor = object[QStringLiteral("__CURSOR")].toString();
             break;
         }
 
         JournalEntry entry;
-        quint64 timestampUsec = object[QStringLiteral("__REALTIME_TIMESTAMP")].toVariant().value<quint64>();
+        auto timestampUsec = object[QStringLiteral("__REALTIME_TIMESTAMP")].toVariant().value<quint64>();
         entry.date.setMSecsSinceEpoch(timestampUsec / 1000);
         entry.message = object[QStringLiteral("MESSAGE")].toString();
         if (entry.message.isEmpty()) {
             // MESSAGE field contains a JSON array of bytes.
             QByteArray stringBytes;
             QJsonArray a = object[QStringLiteral("MESSAGE")].toArray();
-            for (int i = 0; i < a.size(); i++)
+            for (int i = 0; i < a.size(); i++) {
                 stringBytes.append(a[i].toVariant().value<char>());
+            }
             entry.message = QString::fromUtf8(stringBytes);
         }
         entry.message.remove(QRegularExpression(QLatin1String(ConsoleColorEscapeSequence)));
         entry.priority = object[QStringLiteral("PRIORITY")].toVariant().value<int>();
         entry.bootID = object[QStringLiteral("_BOOT_ID")].toString();
         QString unit = object[QStringLiteral("SYSLOG_IDENTIFIER")].toString();
-        if (unit.isEmpty())
+        if (unit.isEmpty()) {
             unit = object[QStringLiteral("_SYSTEMD_UNIT")].toString();
+        }
         entry.unit = unit;
 
         entries << entry;
@@ -223,85 +222,86 @@ void JournaldNetworkAnalyzer::parseEntries(QByteArray &data, Analyzer::ReadingMo
     if (entries.empty()) {
         logDebug() << "Received no entries.";
     } else {
-        insertionLocking.lock();
-        logViewModel->startingMultipleInsertions();
+        mInsertionLocking.lock();
+        mLogViewModel->startingMultipleInsertions();
 
         if (FullRead == readingMode) {
-            emit statusBarChanged(i18n("Reading journald entries..."));
+            Q_EMIT statusBarChanged(i18n("Reading journald entries..."));
             // Start displaying the loading bar.
-            emit readFileStarted(*logMode, LogFile(), 0, 1);
+            Q_EMIT readFileStarted(*mLogMode, LogFile(), 0, 1);
         }
 
         // Add journald entries to the model.
         int entriesInserted = updateModel(entries, readingMode);
 
-        logViewModel->endingMultipleInsertions(readingMode, entriesInserted);
+        mLogViewModel->endingMultipleInsertions(readingMode, entriesInserted);
 
         if (FullRead == readingMode) {
-            emit statusBarChanged(i18n("Journald entries loaded successfully."));
+            Q_EMIT statusBarChanged(i18n("Journald entries loaded successfully."));
 
             // Stop displaying the loading bar.
-            emit readEnded();
+            Q_EMIT readEnded();
         }
 
         // Inform LogManager that new lines have been added.
-        emit logUpdated(entriesInserted);
+        Q_EMIT logUpdated(entriesInserted);
 
-        insertionLocking.unlock();
+        mInsertionLocking.unlock();
     }
 }
 
 void JournaldNetworkAnalyzer::sendRequest(RequestType requestType)
 {
-    if (m_reply)
-        m_reply->deleteLater();
+    if (mReply) {
+        mReply->deleteLater();
+    }
 
-    m_currentRequest = requestType;
+    mCurrentRequest = requestType;
 
     QNetworkRequest request;
     QString url;
 
     switch (requestType) {
     case RequestType::SyslogIds:
-        url = m_syslogIdUrl;
+        url = mSyslogIdUrl;
         break;
     case RequestType::Units:
-        url = m_systemdUnitsUrl;
+        url = mSystemdUnitsUrl;
         break;
     case RequestType::EntriesFull: {
-        url = m_entriesUrlFull;
+        url = mEntriesUrlFull;
         int entries = KSystemLogConfig::maxLines();
         request.setRawHeader("Accept", "application/json");
         request.setRawHeader("Range", QStringLiteral("entries=:-%1:%2").arg(entries - 1).arg(entries).toUtf8());
     } break;
     case RequestType::EntriesUpdate:
-        url = m_entriesUrlUpdating;
+        url = mEntriesUrlUpdating;
         request.setRawHeader("Accept", "application/json");
-        request.setRawHeader("Range", QStringLiteral("entries=%1").arg(m_cursor).toUtf8());
+        request.setRawHeader("Range", QStringLiteral("entries=%1").arg(mCursor).toUtf8());
     default:
         break;
     }
 
     request.setUrl(QUrl(url));
     logDebug() << "Journal network analyzer requested" << url;
-    m_reply = m_networkManager.get(request);
-    connect(m_reply, &QNetworkReply::finished, this, &JournaldNetworkAnalyzer::httpFinished);
-    connect(m_reply, &QNetworkReply::readyRead, this, &JournaldNetworkAnalyzer::httpReadyRead);
+    mReply = mNetworkManager.get(request);
+    connect(mReply, &QNetworkReply::finished, this, &JournaldNetworkAnalyzer::httpFinished);
+    connect(mReply, &QNetworkReply::readyRead, this, &JournaldNetworkAnalyzer::httpReadyRead);
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect(m_reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &JournaldNetworkAnalyzer::httpError);
+    connect(mReply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &JournaldNetworkAnalyzer::httpError);
 #else
-    connect(m_reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::errorOccurred), this, &JournaldNetworkAnalyzer::httpError);
+    connect(mReply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::errorOccurred), this, &JournaldNetworkAnalyzer::httpError);
 #endif
 }
 
 void JournaldNetworkAnalyzer::updateStatus(const QString &status)
 {
-    QString newStatus = m_baseUrl;
-    if (!m_filterName.isEmpty()) {
-        newStatus += QLatin1String(" - ") + m_filterName;
+    QString newStatus = mBaseUrl;
+    if (!mFilterName.isEmpty()) {
+        newStatus += QLatin1String(" - ") + mFilterName;
     }
     if (!status.isEmpty()) {
         newStatus += QLatin1String(" - ") + status;
     }
-    emit statusChanged(newStatus);
+    Q_EMIT statusChanged(newStatus);
 }
