@@ -21,12 +21,11 @@
 
 #include "openLogMode.h"
 
-#include <QString>
 #include <QFileDialog>
+#include <QString>
 
 #include <KLocalizedString>
 
-#include <KToggleAction>
 #include <KMessageBox>
 
 #include "logging.h"
@@ -36,7 +35,7 @@
 
 OpenLogMode::OpenLogMode(QWidget *parent)
     : LogMode(QStringLiteral(OPEN_LOG_MODE_ID), i18n("Log File"), QStringLiteral(OPEN_MODE_ICON))
-    , parent(parent)
+    , mParent(parent)
 {
     d->logModeConfigurationWidget = nullptr;
 
@@ -55,26 +54,25 @@ Analyzer *OpenLogMode::createAnalyzer(const QVariant &options)
     return new OpenAnalyzer(this);
 }
 
-QList<LogFile> OpenLogMode::createLogFiles()
+QVector<LogFile> OpenLogMode::createLogFiles()
 {
     // Open a standard Filedialog
-    QUrl openingFileName(QFileDialog::getOpenFileUrl(parent, i18n("Open Location"), QUrl(), QString()));
+    const QUrl openingFileName(QFileDialog::getOpenFileUrl(mParent, i18n("Open Location"), QUrl(), QString()));
     logDebug() << "Opening file : " << openingFileName.url();
 
     if (openingFileName.isEmpty()) {
-        return QList<LogFile>();
+        return QVector<LogFile>();
     }
 
     if (openingFileName.isValid()) {
-        LogFile logFile(openingFileName, Globals::instance().informationLogLevel());
-        QList<LogFile> logFiles;
-        logFiles.append(logFile);
+        const LogFile logFile(openingFileName, Globals::instance().informationLogLevel());
+        const QVector<LogFile> logFiles{logFile};
 
         return logFiles;
     }
 
-    QString message(i18n("Malformed URL. Unable to open this file."));
-    KMessageBox::error(parent, message, i18n("Unable to open this file."), KMessageBox::Notify);
+    const QString message(i18n("Malformed URL. Unable to open this file."));
+    KMessageBox::error(mParent, message, i18n("Unable to open this file."), KMessageBox::Notify);
 
-    return QList<LogFile>();
+    return QVector<LogFile>();
 }
