@@ -47,14 +47,14 @@ class OpenLogMode : public LogMode
 public:
     explicit OpenLogMode(QWidget *parent);
 
-    ~OpenLogMode();
+    ~OpenLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 
 private:
-    QWidget *parent;
+    QWidget *const mParent;
 };
 
 #endif // _OPEN_LOG_MODE_H
