@@ -44,11 +44,11 @@ class SystemLogMode : public LogMode
 public:
     explicit SystemLogMode();
 
-    ~SystemLogMode();
+    ~SystemLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _SYSTEM_LOG_MODE_H
