@@ -21,18 +21,15 @@
 
 #include "xsessionFactory.h"
 
-
 #include "logMode.h"
 #include "logging.h"
 
 #include "simpleAction.h"
 #include "xsessionLogMode.h"
 
-
 QList<LogMode *> XSessionLogModeFactory::createLogModes() const
 {
-    QList<LogMode *> logModes;
-    logModes.append(new XSessionLogMode());
+    const QList<LogMode *> logModes{new XSessionLogMode()};
     return logModes;
 }
 
@@ -40,10 +37,11 @@ LogModeAction *XSessionLogModeFactory::createLogModeAction() const
 {
     LogMode *logMode = Globals::instance().findLogMode(QStringLiteral(X_SESSION_LOG_MODE_ID));
 
-    if (!logMode->filesExist())
+    if (!logMode->filesExist()) {
         return nullptr;
+    }
 
-    SimpleAction *logModeAction = new SimpleAction(logMode->action(), logMode);
+    auto logModeAction = new SimpleAction(logMode->action(), logMode);
 
     logModeAction->setCategory(LogModeAction::OthersCategory);
 
